aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/staging/most/sound
diff options
context:
space:
mode:
authorChristian Gromm <christian.gromm@microchip.com>2019-12-13 13:04:15 +0100
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2019-12-17 13:50:04 +0100
commit45917e79202c7a0b67f1331c154afba77a3d4a1e (patch)
treedd4e5fda89d60418370a72d4bf9c6533b5be1574 /drivers/staging/most/sound
parentstaging: most: rename core.h to most.h (diff)
downloadlinux-dev-45917e79202c7a0b67f1331c154afba77a3d4a1e.tar.xz
linux-dev-45917e79202c7a0b67f1331c154afba77a3d4a1e.zip
staging: most: rename struct core_component
The stuctures defined in the most.h header file will be exposed to the kernel once the file is moved out of the staging area. That's why the name is changed into something more descriptive. Reported-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org> Signed-off-by: Christian Gromm <christian.gromm@microchip.com> Link: https://lore.kernel.org/r/1576238662-16512-3-git-send-email-christian.gromm@microchip.com Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/most/sound')
-rw-r--r--drivers/staging/most/sound/sound.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/staging/most/sound/sound.c b/drivers/staging/most/sound/sound.c
index 38642b2be306..23baf4bd7c12 100644
--- a/drivers/staging/most/sound/sound.c
+++ b/drivers/staging/most/sound/sound.c
@@ -22,7 +22,7 @@
#define DRIVER_NAME "sound"
#define STRING_SIZE 80
-static struct core_component comp;
+static struct most_component comp;
/**
* struct channel - private structure to keep channel specific data
@@ -736,9 +736,9 @@ static int audio_tx_completion(struct most_interface *iface, int channel_id)
}
/**
* Initialization of the struct core_component
*/
-static struct core_component comp = {
+static struct most_component comp = {
.mod = THIS_MODULE,
.name = DRIVER_NAME,
.probe_channel = audio_probe_channel,
@@ -736,9 +736,9 @@ static int audio_tx_completion(struct most_interface *iface, int channel_id)
}
/**
- * Initialization of the struct core_component
+ * Initialization of the struct most_component
*/